@@ -1,4 +1,4 @@
-#  Copyright (c) 2023 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
+#  Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
 #  All rights reserved.
 #
 #  This file is part of the gsDesign2 program.
@@ -19,6 +19,8 @@
 utils::globalVariables(
   unique(
     c(
+      # From data.table expressions
+      ".", ".SD",
       # From `ahr()`
       c("stratum", "rate", "hr", "treatment", "time", "info0", "info"),
       # From `as_gt.gs_design()`
