@@ -1,4 +1,4 @@
-#  Copyright (c) 2023 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
+#  Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
 #  All rights reserved.
 #
 #  This file is part of the gsDesign2 program.
@@ -22,7 +22,7 @@
 #' Group sequential design power using average hazard ratio under
 #' non-proportional hazards.
 #'
-#' @param enroll_rate Enrollment rates.
+#' @inheritParams ahr
 #' @param fail_rate Failure and dropout rates.
 #' @param ratio Experimental:Control randomization ratio (not yet implemented).
 #' @param event Targeted event at each analysis.
@@ -88,13 +88,13 @@
 #' library(gsDesign2)
 #' library(dplyr)
 #'
-#' # Example 1 -----------------------------------------------------------------
+#' # Example 1 ----
 #' # The default output of `gs_power_ahr()` is driven by events,
 #' # i.e., `event = c(30, 40, 50)`, `analysis_time = NULL`
 #' \donttest{
 #' gs_power_ahr()
 #' }
-#' # Example 2 -----------------------------------------------------------------
+#' # Example 2 ----
 #' # 2-sided symmetric O'Brien-Fleming spending bound, driven by analysis time,
 #' # i.e., `event = NULL`, `analysis_time = c(12, 24, 36)`
 #'
@@ -108,7 +108,7 @@
 #'   lpar = list(sf = gsDesign::sfLDOF, total_spend = 0.025, param = NULL, timing = NULL)
 #' )
 #'
-#' # Example 3 -----------------------------------------------------------------
+#' # Example 3 ----
 #' # 2-sided symmetric O'Brien-Fleming spending bound, driven by event,
 #' # i.e., `event = c(20, 50, 70)`, `analysis_time = NULL`
 #' \donttest{
@@ -122,7 +122,7 @@
 #'   lpar = list(sf = gsDesign::sfLDOF, total_spend = 0.025, param = NULL, timing = NULL)
 #' )
 #' }
-#' # Example 4 -----------------------------------------------------------------
+#' # Example 4 ----
 #' # 2-sided symmetric O'Brien-Fleming spending bound,
 #' # driven by both `event` and `analysis_time`, i.e.,
 #' # both `event` and `analysis_time` are not `NULL`,
@@ -140,39 +140,38 @@
 #'   lpar = list(sf = gsDesign::sfLDOF, total_spend = 0.025, param = NULL, timing = NULL)
 #' )
 #' }
-gs_power_ahr <- function(enroll_rate = tibble(
-                           stratum = "All",
-                           duration = c(2, 2, 10),
-                           rate = c(3, 6, 9)
-                         ),
-                         fail_rate = tibble(
-                           stratum = "All",
-                           duration = c(3, 100),
-                           fail_rate = log(2) / c(9, 18),
-                           hr = c(.9, .6),
-                           dropout_rate = rep(.001, 2)
-                         ),
-                         event = c(30, 40, 50),
-                         analysis_time = NULL,
-                         upper = gs_b,
-                         upar = gsDesign(
-                           k = length(event),
-                           test.type = 1,
-                           n.I = event,
-                           maxn.IPlan = max(event),
-                           sfu = sfLDOF,
-                           sfupar = NULL
-                         )$upper$bound,
-                         lower = gs_b,
-                         lpar = c(qnorm(.1), rep(-Inf, 2)),
-                         test_lower = TRUE,
-                         test_upper = TRUE,
-                         ratio = 1,
-                         binding = FALSE,
-                         info_scale = c("h0_h1_info", "h0_info", "h1_info"),
-                         r = 18,
-                         tol = 1e-6,
-                         interval = c(.01, 100)) {
+gs_power_ahr <- function(
+    enroll_rate = define_enroll_rate(
+      duration = c(2, 2, 10),
+      rate = c(3, 6, 9)
+    ),
+    fail_rate = define_fail_rate(
+      duration = c(3, 100),
+      fail_rate = log(2) / c(9, 18),
+      hr = c(.9, .6),
+      dropout_rate = rep(.001, 2)
+    ),
+    event = c(30, 40, 50),
+    analysis_time = NULL,
+    upper = gs_b,
+    upar = gsDesign(
+      k = length(event),
+      test.type = 1,
+      n.I = event,
+      maxn.IPlan = max(event),
+      sfu = sfLDOF,
+      sfupar = NULL
+    )$upper$bound,
+    lower = gs_b,
+    lpar = c(qnorm(.1), rep(-Inf, 2)),
+    test_lower = TRUE,
+    test_upper = TRUE,
+    ratio = 1,
+    binding = FALSE,
+    info_scale = c("h0_h1_info", "h0_info", "h1_info"),
+    r = 18,
+    tol = 1e-6,
+    interval = c(.01, 100)) {
   # Get the number of analysis
   n_analysis <- max(length(event), length(analysis_time), na.rm = TRUE)
 
@@ -191,14 +190,14 @@ gs_power_ahr <- function(enroll_rate = tibble(
     two_sided <- TRUE
   }
 
-  # Calculate the asymptotic variance and statistical information --------------
+  # Calculate the asymptotic variance and statistical information ----
   x <- gs_info_ahr(
     enroll_rate = enroll_rate, fail_rate = fail_rate,
     ratio = ratio, event = event, analysis_time = analysis_time,
     interval = interval
   )
 
-  # Given the above statistical information, calculate the power ---------------
+  # Given the above statistical information, calculate the power ----
   y_h1 <- gs_power_npe(
     theta = x$theta,
     info = x$info, info0 = x$info0, info1 = x$info, info_scale = info_scale,
@@ -225,8 +224,8 @@ gs_power_ahr <- function(enroll_rate = tibble(
     binding = binding, r = r, tol = tol
   )
 
-  # Organize the outputs -------------------------------------------------------
-  # summarize the bounds
+  # Organize the outputs ----
+  # Summarize the bounds
   suppressMessages(
     bound <- y_h1 %>%
       mutate(`~hr at bound` = exp(-z / sqrt(info)), `nominal p` = pnorm(-z)) %>%
@@ -238,23 +237,27 @@ gs_power_ahr <- function(enroll_rate = tibble(
       select(analysis, bound, probability, probability0, z, `~hr at bound`, `nominal p`) %>%
       arrange(analysis, desc(bound))
   )
-  # summarize the analysis
+  # Summarize the analysis
   suppressMessages(
     analysis <- x %>%
       select(analysis, time, event, ahr) %>%
       mutate(n = expected_accrual(time = x$time, enroll_rate = enroll_rate)) %>%
-      left_join(y_h1 %>%
-        select(analysis, info, info_frac, theta) %>%
-        unique()) %>%
-      left_join(y_h0 %>%
-        select(analysis, info, info_frac) %>%
-        dplyr::rename(info0 = info, info_frac0 = info_frac) %>%
-        unique()) %>%
+      left_join(
+        y_h1 %>%
+          select(analysis, info, info_frac, theta) %>%
+          unique()
+      ) %>%
+      left_join(
+        y_h0 %>%
+          select(analysis, info, info_frac) %>%
+          dplyr::rename(info0 = info, info_frac0 = info_frac) %>%
+          unique()
+      ) %>%
       select(analysis, time, n, event, ahr, theta, info, info0, info_frac, info_frac0) %>%
       arrange(analysis)
   )
 
-  # Get input parameter to output ----------------------------------------------
+  # Get input parameter to output ----
   input <- list(
     enroll_rate = enroll_rate, fail_rate = fail_rate,
     event = event, analysis_time = analysis_time,
