@@ -1,49 +1,49 @@
 test_that("check enrollments", {
-  expect_warning(expect_error(check_enroll_rate(tibble::tibble(rate = c(2, 4)))))
-  expect_warning(expect_error(check_enroll_rate(tibble::tibble(duration = c(10, 20), rate = c("a", "b")))))
-  expect_warning(expect_error(check_enroll_rate(tibble::tibble(duration = c(10, 20), rate = c(2, -4)))))
+  expect_error(check_enroll_rate(tibble::tibble(rate = c(2, 4))))
+  expect_error(check_enroll_rate(tibble::tibble(duration = c(10, 20), rate = c("a", "b"))))
+  expect_error(check_enroll_rate(tibble::tibble(duration = c(10, 20), rate = c(2, -4))))
 
-  expect_warning(expect_error(check_enroll_rate(tibble::tibble(duration = c(10, 20)))))
-  expect_warning(expect_error(check_enroll_rate(tibble::tibble(rate = c(2, 4), duration = c("a", "b")))))
-  expect_warning(expect_error(check_enroll_rate(tibble::tibble(rate = c(2, 4), duration = c(10, -20)))))
+  expect_error(check_enroll_rate(tibble::tibble(duration = c(10, 20))))
+  expect_error(check_enroll_rate(tibble::tibble(rate = c(2, 4), duration = c("a", "b"))))
+  expect_error(check_enroll_rate(tibble::tibble(rate = c(2, 4), duration = c(10, -20))))
 })
 
 test_that("check fail_rate", {
   # lack duration
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(tibble::tibble(fail_rate = c(0.2, 0.4), dropout_rate = 0.01))
-  ))
+  )
 
   # lack fail_rate
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(tibble::tibble(duration = c(2, 4), dropout_rate = 0.01))
-  ))
+  )
 
   # lack dropout_rate
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(tibble::tibble(fail_rate = c(0.2, 0.4), duration = c(10, 20)))
-  ))
+  )
 
   # check of column `duration`
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(tibble::tibble(fail_rate = c(2, 4), duration = c("a", "b"), dropout_rate = 0.01))
-  ))
+  )
 
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(tibble::tibble(fail_rate = c(2, 4), duration = c(10, -20), dropout_rate = 0.01))
-  ))
+  )
 
   # check of column `fail_rate`
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(tibble::tibble(duration = c(10, 20), fail_rate = c("a", "b"), dropout_rate = 0.01))
-  ))
+  )
 
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(tibble::tibble(duration = c(10, 20), fail_rate = c(2, -4), dropout_rate = 0.01))
-  ))
+  )
 
   # check of column `hr`
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(
       tibble::tibble(
         duration = c(10, 20),
@@ -51,9 +51,9 @@ test_that("check fail_rate", {
         dropout_rate = 0.01, hr = "a"
       )
     )
-  ))
+  )
 
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(
       tibble::tibble(
         duration = c(10, 20),
@@ -61,10 +61,10 @@ test_that("check fail_rate", {
         dropout_rate = 0.01, hr = -1
       )
     )
-  ))
+  )
 
   # check of column `dropoutRate`
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(
       tibble::tibble(
         duration = c(10, 20),
@@ -72,9 +72,9 @@ test_that("check fail_rate", {
         dropout_rate = "a", hr = 0.6
       )
     )
-  ))
+  )
 
-  expect_warning(expect_error(
+  expect_error(
     check_fail_rate(
       tibble::tibble(
         duration = c(10, 20),
@@ -82,7 +82,7 @@ test_that("check fail_rate", {
         dropout_rate = -1, hr = 0.6
       )
     )
-  ))
+  )
 })
 
 test_that("check enrollments and fail_rate together", {
@@ -159,3 +159,27 @@ test_that("check check_info_frac", {
   expect_error(check_info_frac(c(2 / 3, 1 / 3, 1)))
   expect_error(check_info_frac(c(2 / 3, 3 / 4)))
 })
+
+test_that("check_enroll_rate does not require a specific class", {
+  enroll_rate <- define_enroll_rate(
+    duration = c(2, 2, 10),
+    rate = c(3, 6, 9)
+  )
+  # remove class "enroll_rate"
+  class_orig <- class(enroll_rate)
+  class(enroll_rate) <- class_orig[class_orig != "enroll_rate"]
+  expect_silent(check_enroll_rate(enroll_rate))
+})
+
+test_that("check_fail_rate does not require a specific class", {
+  fail_rate <- define_fail_rate(
+    duration = c(3, 100),
+    fail_rate = log(2) / c(9, 18),
+    hr = c(0.9, 0.6),
+    dropout_rate = 0.001
+  )
+  # remove class "fail_rate"
+  class_orig <- class(fail_rate)
+  class(fail_rate) <- class_orig[class_orig != "fail_rate"]
+  expect_silent(check_fail_rate(fail_rate))
+})
